
const liste_radios = [
	["RTL", "https://streamer-01.rtl.fr/rtl-1-44-128?listen=webCwsBCggNCQgLDQUGBAcGBg"],
	["France Inter" , "https://icecast.radiofrance.fr/franceinter-hifi.aac"],
	["Arrêt", "./sounds/confetti.mp3"],
	["NRJ", "http://scdn.nrjaudio.fm/adwz2/fr/30401/mp3_128.mp3?origine=fluxradios"],
	["Europe1","http://stream.europe1.fr/europe1.aac"]
]
const audio = document.querySelector("audio");
const pads=document.querySelectorAll(".pads div div"); // Liste des pads
let avertissement = "";
	
   pads[5].addEventListener('click', afficherDonnees);

// Evenement click de chaque pad (sauf le pad5):   
   pads.forEach((pad, n) => {
	if (n == 5 ) return;
	pad.innerHTML = liste_radios[n][0];
	pad.addEventListener('click', (e)=> {
		let index = liste_radios.findIndex( (radios) => radios[0] == e.target.innerHTML )
		audio.src = liste_radios[index][1]; // mettre le src au dernier moment
		audio.play();
    });
  });
  
// Gestion du slider Volume
	let slideVolume = document.querySelector("#slideVolume");
	slideVolume.addEventListener( 'input', (e) => {
		let volume = Number(e.target.value) / 100;
		audio.volume = volume;
	});

////////////////////////////////////////////////////////////
///  Affichage des données stockées par IndexedDB
///   Anciennes si pas de connexion réseau
////////////////////////////////////////////////////////////
async function afficherDonnees() {	

	try  {
		// On attend le succès (ou un echec) de ces fonctions avant de continuer
		const data = await chargerDonnees();
		const enr = await enregistrerDonnees(data);
	}
	catch (err) { /*Sauf si erreur réseau*/
			console.log ("catch:", err, "Utilisation des données stockées");
			avertissement = "(Serveur indisponible. Données archivées)"
	}
	
	let db = '';
	let openRequest = indexedDB.open('meteo', 2);

	//////////////////////////////////////////////////
	openRequest.onupgradeneeded = function(){
		db = openRequest.result;
		if (!db.objectStoreNames.contains('meteo')){
			db.createObjectStore('meteo', {keyPath: 'id', autoIncrement:true });
		}
	};

	//////////////////////////////////////////////////
	openRequest.onerror = function(){
		alert('Impossible d\'accéder à IndexedDB');
	};

	/////////////////////////////////////////////////
	openRequest.onsuccess = function(){
		db = openRequest.result;
		let transaction = db.transaction('meteo', 'readwrite');
		let clients = transaction.objectStore('meteo');
		let lire = clients.getAll();

		lire.onerror = function(){
			alert('Erreur : ' + lire.error);
		};
		
		/// Affichage des données
		lire.onsuccess =  (e) => miseEnPageData(e.target.result);		
	}
}

////////////////////////////////////////////////////////////
/// Objectif : Récupérer les données sur le serveur
///  (on ne passe pas par le Service Worker):
///  fetch et json sont des promesses mais pas la fonction elle-même
///   En retournant une promesse, on gère mieux sa synchronisation
///    lors de l'appel.
////////////////////////////////////////////////////////////
function chargerDonnees() {
	return new Promise ( (resolve, reject) => {
		fetch('http://lycvauv.myfw.us/adl/maj.php')
		.then( (reponse) => reponse.json())
			.then( (data) => {console.log("Loaded:",data); resolve(data);}) 
		.catch( (error) => {console.log("Charger données:" , error);  reject(error);});
	});
}

////////////////////////////////////////////////////////////
/// Objectif : Enregistrer les données en local avec IndexedDB.
/// En retournant une promesse, on gère mieux sa synchronisation
///    lors de l'appel.
////////////////////////////////////////////////////////////
async function enregistrerDonnees (data) {
	
	if (!data) { console.log("rec:Pas de data"); throw "E1";}
	
	let db = '';
	let openRequest = indexedDB.open('meteo', 2);
	console.log("rec:openRequest:", openRequest);	

	//////////////////////////////////////////////////
	openRequest.onupgradeneeded =  function(){
		db = openRequest.result;
			console.log("rec:Update");
		if (!db.objectStoreNames.contains('meteo')){
			db.createObjectStore('meteo', {keyPath: 'id', autoIncrement:true });
			console.log("rec:Updated");
		}
	};

	//////////////////////////////////////////////////
	openRequest.onerror = function(){
		alert('Impossible d\'accéder à IndexedDB'); throw "E2";
	};

	//////////////////////////////////////////////////
	openRequest.onsuccess =  function(){
		db = openRequest.result;
		let transaction = db.transaction('meteo', 'readwrite');
			console.log("rec:Opened");
		
		/// /////////////////
		transaction.onerror = (event) => {
			console.log('Transaction not opened due to error: ',transaction.error);
			throw "E3";
		}
		
		/// //////////////////
		transaction.oncomplete = function(){
			//alert('Transaction terminée');
		};

		let tupple = transaction.objectStore('meteo');
		
		/// Effacement des anciennes données
		const objectStoreRequest = tupple.clear();
		console.log('rec:Data erased');
		
		/// Enregistrement des données
		objectStoreRequest.onsuccess =  function (event) {
			console.log("rec:Saving:", data);	
			
			data.forEach( (ligne) => {
				let cli = {
					/*id: ligne.id,*/
					date: ligne.date,
					t: ligne.t
				};
				//use put versus add to always write, even if exists
				let ajout = tupple.add(cli);
				ajout.onsuccess = function(){ };
				ajout.onerror = function(){	alert('Erreur : ' + ajout.error); throw "E5";};
			});
			console.log("rec:Saved");
			return; // Fin de la promesse
		};
	};
}
 
 ////////////////////////////////////////////////////////////
/// Objectif : Faire un affichage des données
///
////////////////////////////////////////////////////////////
function miseEnPageData(data) {
	let total = 0;
	data.forEach( (tupple) => total +=  (tupple.t / 100) );
	let moyenne = Math.round(total / data.length) / 10;
	let temp = Math.round(data[0].t / 100) / 10;
	let txt = `
		<div>Dernière Température mesurée : ${temp} °C</div>
		<div>Date de la mesure : ${data[0].date}</div>
		<div>Moyenne ${data.length} dernières mesures : ${moyenne}°C</div>
		<div style='font-size:0.7em'>${avertissement}</div>`;
	let modal = document.querySelector('.modal');
	modal.innerHTML = txt;
	modal.style.display = 'flex';
	modal.onclick = ()=> modal.style.display = 'none';
	
	avertissement = "";
}
